@@ -2566,7 +2566,8 @@ sub _prev_cwd { return( shift->_set_get_scalar( '_prev_cwd', @_ ) ); }
 
 # XXX IO::File class modification
 {
-    package IO::File;
+    package
+        IO::File;
     
     sub flock { CORE::flock( shift( @_ ), shift( @_ ) ); }
 }
